@@ -449,8 +449,6 @@ class Athena(BaseAthena):
     )
     """
 
-    tools: WrappedToolsClient
-
     def __init__(
         self,
         *,
@@ -484,12 +482,17 @@ class Athena(BaseAthena):
             timeout=timeout,
             httpx_client=httpx_client,
         )
-        self.tools = WrappedToolsClient(client_wrapper=self._client_wrapper)
-        self.query = WrappedQueryClient(client_wrapper=self._client_wrapper)
+        self._tools: typing.Optional[WrappedToolsClient] = None
         self.llm = AthenaModel(
             base_url=base_url or environment.value, api_key=api_key, timeout=timeout
         )
 
+    @property
+    def tools(self) -> WrappedToolsClient:
+        if self._tools is None:
+            self._tools = WrappedToolsClient(client_wrapper=self._client_wrapper)
+        return self._tools
+
 
 class AsyncAthena(AsyncBaseAthena):
     """
@@ -522,8 +525,6 @@ class AsyncAthena(AsyncBaseAthena):
     )
     """
 
-    tools: WrappedAsyncToolsClient
-
     def __init__(
         self,
         *,
@@ -550,6 +551,7 @@ class AsyncAthena(AsyncBaseAthena):
                 environment = cast(AthenaEnvironment, AutodetectedEnvironments.CURRENT)
             else:
                 environment = AthenaEnvironment.PRODUCTION
+        self._tools: typing.Optional[WrappedAsyncToolsClient] = None
         super().__init__(
             base_url=base_url,
             environment=environment,  # type: ignore[arg-type]
@@ -557,8 +559,12 @@ class AsyncAthena(AsyncBaseAthena):
             timeout=timeout,
             httpx_client=httpx_client,
         )
-        self.tools = WrappedAsyncToolsClient(client_wrapper=self._client_wrapper)
-        self.query = WrappedAsyncQueryClient(client_wrapper=self._client_wrapper)
+
+    @property
+    def tools(self) -> WrappedAsyncToolsClient:
+        if self._tools is None:
+            self._tools = WrappedAsyncToolsClient(client_wrapper=self._client_wrapper)
+        return self._tools
 
 
 def _read_json_frame(model: DataFrameRequestOut) -> "pd.DataFrame":
